@@ -7,19 +7,23 @@ from .config import debug
 stdout = sys.stdout
 notebook = False
 
-def is_notebook():
-  try:
-    from IPython import get_ipython
-  except Exception: return False
-  if 'COLAB_GPU' in os.environ: return True
 
-  shell = get_ipython().__class__.__name__
-  if shell == 'ZMQInteractiveShell':
-    return True
+def is_notebook():
+    try:
+        from IPython import get_ipython
+    except Exception:
+        return False
+    if "COLAB_GPU" in os.environ:
+        return True
+
+    shell = get_ipython().__class__.__name__
+    if shell == "ZMQInteractiveShell":
+        return True
+
 
 if is_notebook():
-  notebook = True
-  stdout = subprocess.PIPE
+    notebook = True
+    stdout = subprocess.PIPE
 
 
 def supports_color():
@@ -111,7 +115,7 @@ def com_io():
         )
     except Exception as e:
         print(
-            "--====--\t--====--\n\nBridge failed to spawn JS process!\n\nDo you have Node.js 15 or newer installed? Get it at https://nodejs.org/\n\n--====--\t--====--"
+            "--====--\t--====--\n\nBridge failed to spawn JS process!\n\nDo you have Node.js 16 or newer installed? Get it at https://nodejs.org/\n\n--====--\t--====--"
         )
         stop()
         raise e
@@ -128,10 +132,12 @@ def com_io():
         stderr_lines.append(proc.stderr.readline())
         config.event_loop.queue.put("stdin")
 
+
 def stdout_read():
     while proc.poll() is None:
         print(proc.stdout.readline().decode("utf-8"))
 
+
 def start():
     global com_thread
     com_thread = threading.Thread(target=com_io, args=(), daemon=True)
@@ -141,8 +147,6 @@ def start():
 def stop():
     try:
         proc.terminate()
-        com_thread.stop()
-        stdout_thread.stop()
     except Exception:
         pass
     config.event_loop = None
@@ -154,7 +158,6 @@ def stop():
     config.fast_mode = False
 
 
-
 def is_alive():
     return proc.poll() is None
 
